#!/bin/sh
#----------------------------------------------------------------------------
# /var/install/config.d/php8-cli-update.sh - parameter update script
#
# Copyright (c) 2021 
# Last Update:  $Id: php8-cli-update.sh 61813 2018-12-30 00:52:16Z schlotze $
#
# Copyright (c) 2021 the eisfair team, team(at)eisfair(dot)org
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#----------------------------------------------------------------------------

### -------------------------------------------------------------------------
### major variables
### -------------------------------------------------------------------------
# presonal data
# -------------
my_name='Sebastian Scholze'
my_initial='schlotze'
my_copy="`date +%Y` ${my_name} <sebastian(at)eisfair(dot)org>"

# date settings
# -------------
datum_creation="2006-05-08"
datum_update=`date +%Y-%m-%d`

# name of the current package
# ---------------------------
packages_name=php8-cli


### -------------------------------------------------------------------------
### include configlib for using printvar
### -------------------------------------------------------------------------
. /var/install/include/configlib

### -------------------------------------------------------------------------
### Set the default values for configuration
### -------------------------------------------------------------------------
START_PHP8CLI='yes'
PHP8CLI_MAX_EXECUTION_TIME='30'
PHP8CLI_DISPLAY_ERRORS='yes'
PHP8CLI_LOG_ERROR='no'
PHP8CLI_SENDMAIL_PATH=''
PHP8CLI_SENDMAIL_APP=''
PHP8CLI_DATE_TIMEZONE='Europe/Berlin'

PHP8CLI_MAX_POST_SIZE='8M'
PHP8CLI_MAX_UPLOAD_FILESIZE='2M'
PHP8CLI_MEMORY_LIMIT='20M'
PHP8CLI_UPLOAD_DIR='/tmp'

# ---------------------------------------------------------------------------
# Extensions
PHP8CLI_EXT_CACHE='no'
PHP8CLI_EXT_SOAP='no'
PHP8CLI_EXT_LDAP='no'

PHP8CLI_EXT_MYSQL='no'
PHP8CLI_EXT_MYSQL_SOCKET='/run/mysql/mysql.sock'
PHP8CLI_EXT_MYSQL_HOST=''
PHP8CLI_EXT_MYSQL_PORT='3306'
PHP8CLI_EXT_MSSQL='no'
PHP8CLI_EXT_PGSQL='no'
PHP8CLI_EXT_INTER='no'
PHP8CLI_EXT_SQLITE3='no'

### ---------------------------------------------------------------------------
### read old configuration and rename old variables
### ---------------------------------------------------------------------------
read_old_config()
{
    # read old values
    if [ -f /etc/config.d/${packages_name} ]
    then
        . /etc/config.d/${packages_name}
    fi
}

### ---------------------------------------------------------------------------
### Write config and default files
### ---------------------------------------------------------------------------
make_config_file()
{
    internal_conf_file=${1}
    {
    echo "#------------------------------------------------------------------------------"
    echo "# ${internal_conf_file} - configuration for ${packages_name}"
    echo "#"
    echo "# Copyright (c) 2021"
    echo "# Last Update:  ${datum_update} ${my_initial}"
    echo "#"
    echo "# Copyright (c) ${my_copy}"
    echo "#"
    echo "# This program is free software; you can redistribute it and/or modify"
    echo "# it under the terms of the GNU General Public License as published by"
    echo "# the Free Software Foundation; either version 2 of the License, or"
    echo "# (at your option) any later version."
    echo "#------------------------------------------------------------------------------"

    #------------------------------------------------------------------------------
    printgroup  "General settings"
    #------------------------------------------------------------------------------

	printvar "START_PHP8CLI" ""
    printvar "PHP8CLI_MAX_EXECUTION_TIME" "Time in sec. until the script will be"
    printvar "" "terminated."
    printvar "" "default: 30"
    printvar

    printvar "PHP8CLI_DISPLAY_ERRORS" "Show syntaxerrors of your PHP-Scripts"
    printvar "" "in your Browser."
    printvar "" "yes=ON (default) / no=OFF"
    printvar

    printvar "PHP8CLI_LOG_ERROR" "Write Error to an logfile"
    printvar "" "yes=ON / no=OFF (default)"
    printvar

    printvar "PHP8CLI_SENDMAIL_PATH" "Here you can change your path to"
    printvar "" "sendmail if needed."
    printvar "" "default: empty"
    printvar "" "(this will use the deafult one)"
    printvar

    printvar "PHP8CLI_SENDMAIL_APP" "Enter additional command that needed to"
    printvar "" "run sendmail correctly."
    printvar "" "default: empty"
    printvar "" "(this will use the deafult one)"
    
    printvar "PHP8CLI_DATE_TIMEZONE" "Enter your timezone here"

    #------------------------------------------------------------------------------
    printgroup "Memory Settings"
    #------------------------------------------------------------------------------

    printvar "PHP8CLI_MAX_POST_SIZE" "Maximal POST size"
    printvar "" "If you use the POST-Method for uploads"
    printvar "" "this value must be bigger/equal than"
    printvar "" "PHP8CLI_MAX_UPLOAD_FILESIZE"
    printvar "" "default: 8M --> meens 8 Magabytes"
    printvar

    printvar "PHP8CLI_MAX_UPLOAD_FILESIZE" "Max. filesize for uploads"
    printvar "" "default: 2M --> meens 2 Megabytes"
    printvar

    printvar "PHP8CLI_MEMORY_LIMIT" "Memory, PHP is allowed to use"
    printvar "" "default: 8M --> meens 8 Megabytes"
    printvar

    printvar "PHP8CLI_UPLOAD_DIR" "Where to temporary save uploaded file"
    printvar "" "default: /tmp"

    #------------------------------------------------------------------------------
    printgroup "EXTENSION CONFIGURATION - CACHE"
    #------------------------------------------------------------------------------
    printvar "PHP8CLI_EXT_CACHE" "Activate chaching module in PHP."
    printvar "" "apcu: for APCu, redis: for Redis"
    printvar "" "default: no -> switch chaching module off"
    printvar "PHP8CLI_EXT_SOAP" "Activate SOAP module in PHP."
    printvar "PHP8CLI_EXT_LDAP" "Activate LDAP module in PHP."
    #------------------------------------------------------------------------------
    printgroup "EXTENSION CONFIGURATION - DATABASE"
    #------------------------------------------------------------------------------
    printvar "PHP8CLI_EXT_MYSQL" "include MySQL extension in PHP"
    printvar "PHP8CLI_EXT_MYSQL_SOCKET" "default socket to connect the"
    printvar "" "MySQL Database."
    printvar "" "Eisfair-1 -> /run/mysql/mysql.sock"
    printvar "" "MySQL 3.x.y -> /tmp/mysql.sock"
    printvar "PHP8CLI_EXT_MYSQL_HOST" "Hostname or IP address if use port connect"
    printvar "PHP8CLI_EXT_MYSQL_PORT" "MySQL connect port (3306)"
    printvar "PHP8CLI_EXT_MSSQL" "include msSQL extension in PHP"
    printvar "PHP8CLI_EXT_PGSQL" "include PostgreSQL extension in PHP"
    printvar "PHP8CLI_EXT_INTER" "include INTERBASE extension in PHP"
    printvar "PHP8CLI_EXT_SQLITE3" "include SQLite3 extension in PHP"

    #------------------------------------------------------------------------------
    printend
    #------------------------------------------------------------------------------

    } > ${internal_conf_file}
    # Set rights
    chmod 0600 ${internal_conf_file}
    chown root ${internal_conf_file}
}

### -------------------------------------------------------------------------
### Create the check.d file
### -------------------------------------------------------------------------
make_check_file()
{
cat >/etc/check.d/${packages_name} <<EOF_INT
#--------------------------------------------------------------------------
# /etc/check.d/${packages_name} - eischk check file
#
# Copyright (c) 2005-2006 Eisfair Team
# Copyright (c) ${my_copy}
#
# Copyright (c) 2021 
# Last Update:  ${datum_update} ${my_initial}
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#--------------------------------------------------------------------------
# Variable               OPT_VARIABLE             VARIABLE_N      VALUE

START_PHP8CLI                 -                         -        YESNO
PHP8CLI_MAX_EXECUTION_TIME    START_PHP8CLI             -        NUMERIC
PHP8CLI_DISPLAY_ERRORS        START_PHP8CLI             -        YESNO
PHP8CLI_LOG_ERROR             START_PHP8CLI             -        YESNO
PHP8CLI_MAX_POST_SIZE         START_PHP8CLI             -        NOTEMPTY
PHP8CLI_MAX_UPLOAD_FILESIZE   START_PHP8CLI             -        NOTEMPTY
PHP8CLI_MEMORY_LIMIT          START_PHP8CLI             -        NOTEMPTY
PHP8CLI_UPLOAD_DIR            START_PHP8CLI             -        NOTEMPTY
PHP8CLI_SENDMAIL_PATH         START_PHP8CLI             -        NONE
PHP8CLI_SENDMAIL_APP          START_PHP8CLI             -        NONE
PHP8CLI_DATE_TIMEZONE         START_PHP8CLI             -        PHP8CLI_DATE_TIMEZONE
PHP8CLI_EXT_MYSQL             START_PHP8CLI             -        YESNO
PHP8CLI_EXT_MYSQL_SOCKET      PHP8CLI_EXT_MYSQL         -        PHP8CLI_MYSQL_SOCKET
PHP8CLI_EXT_MYSQL_HOST        PHP8CLI_EXT_MYSQL         -        PHP8CLI_MYSQL_HOST
PHP8CLI_EXT_MYSQL_PORT        PHP8CLI_EXT_MYSQL         -        PHP8CLI_MYSQL_PORT
PHP8CLI_EXT_MSSQL             START_PHP8CLI             -        YESNO
PHP8CLI_EXT_PGSQL             START_PHP8CLI             -        YESNO
PHP8CLI_EXT_INTER             START_PHP8CLI             -        YESNO
PHP8CLI_EXT_SQLITE3           START_PHP8CLI             -        YESNO
PHP8CLI_EXT_CACHE             START_PHP8CLI             -        PHP8CLI_CACHING_MODULE
PHP8CLI_EXT_SOAP              START_PHP8CLI             -        YESNO
PHP8CLI_EXT_LDAP              START_PHP8CLI             -        YESNO
EOF_INT

    # Set rights for check.d file
    chmod 0600 /etc/check.d/${packages_name}
    chown root /etc/check.d/${packages_name}

### ---------------------------------------------------------------------------
### Create the EXTENTED check.d file
### ---------------------------------------------------------------------------
sellist="Europe/Amsterdam|Europe/Andorra|"
sellist="${sellist}Europe/Athens|Europe/Belfast|Europe/Belgrade|Europe/Berlin|Europe/Bratislava|Europe/Brussels|Europe/Bucharest|Europe/Budapest|"
sellist="${sellist}Europe/Chisinau|Europe/Copenhagen|Europe/Dublin|Europe/Gibraltar|Europe/Guernsey|Europe/Helsinki|Europe/Isle_of_Man|Europe/Istanbul|"
sellist="${sellist}Europe/Jersey|Europe/Kaliningrad|Europe/Kiev|Europe/Lisbon|Europe/Ljubljana|Europe/London|Europe/Luxembourg|Europe/Madrid|"
sellist="${sellist}Europe/Malta|Europe/Mariehamn|Europe/Minsk|Europe/Monaco|Europe/Moscow|Europe/Nicosia|Europe/Oslo|Europe/Paris|Europe/Podgorica|"
sellist="${sellist}Europe/Prague|Europe/Riga|Europe/Rome|Europe/Samara|Europe/San_Marino|Europe/Sarajevo|Europe/Simferopol|Europe/Skopje|Europe/Sofia|"
sellist="${sellist}Europe/Stockholm|Europe/Tallinn|Europe/Tirane|Europe/Tiraspol|Europe/Uzhgorod|Europe/Vaduz|Europe/Vatican|Europe/Vienna|Europe/Vilnius|"
sellist="${sellist}Europe/Volgograd|Europe/Warsaw|Europe/Zagreb|Europe/Zaporozhye|Europe/Zurich|Etc/GMT|Etc/GMT+0|Etc/GMT+1|Etc/GMT+10|Etc/GMT+11|"
sellist="${sellist}Etc/GMT+12|Etc/GMT+2|Etc/GMT+3|Etc/GMT+4|Etc/GMT+5|"
sellist="${sellist}Etc/GMT+6|Etc/GMT+7|Etc/GMT+8|Etc/GMT+9|Etc/GMT-0|Etc/GMT-1|Etc/GMT-10|Etc/GMT-11|Etc/GMT-12|Etc/GMT-13|Etc/GMT-14|Etc/GMT-2|"
sellist="${sellist}Etc/GMT-3|Etc/GMT-4|Etc/GMT-5|Etc/GMT-6|Etc/GMT-7|Etc/GMT-8|Etc/GMT-9|Etc/GMT0|Etc/Greenwich|Etc/UCT|Etc/Universal|Etc/UTC|"
sellist="${sellist}Etc/Zulu"

printgpl "${packages_name}.exp" "${datum_update}" "${my_initial}" "${my_name}" > /etc/check.d/${packages_name}.exp
cat >> /etc/check.d/${packages_name}.exp <<EOF_INT
PHP8CLI_MYSQL_SOCKET = '/run/mysql/[0-9]*?/?mysql.sock|/var/run/mysql/[0-9/]*?mysql.sock|/var/run/mysql/mysql.sock|/var/lib/mysql/mysql.sock|/tmp/mysql.sock|()'
                 : 'Must be an absolute path to the database socket, e.g. /var/run/mysql/102/mysql.sock'
PHP8CLI_MYSQL_HOST = 'localhost|(RE:FQDN)|(RE:IPADDR)|()'
                  : 'Use only: localhost, hostname.domain.tld, ip-address or empty for not use'
PHP8CLI_CACHING_MODULE = 'no|apcu|redis|apcu\+redis'
                    : 'Use "apcu" for the APCu chaching module and/or "redis" for accessing redis server. default = "no" -> no chaching modul'
PHP8CLI_DATE_TIMEZONE = "${sellist}"
                    : 'Select a predefinde Date/Timezone'
PHP8CLI_DEFAULT_CHARSET = "${sellistDefaultCharset}"
                    : 'Select a predefinde default charset'
PHP8CLI_MYSQL_PORT = "(RE:EPORT)"
                    : 'Select a Port'

EOF_INT
    # Set rights for check.exp file
    chmod 0600 /etc/check.d/${packages_name}.exp
    chown root /etc/check.d/${packages_name}.exp
}
### ---------------------------------------------------------------------------
### Main
### ---------------------------------------------------------------------------

# 
if [ -f /etc/config.d/php5_ccpp ] && [ ! -f /etc/config.d/php8-cli ]
then
     sed -e 's/PHP5CCPP/PHP8CLI/g' -e 's/php5/php8/g' /etc/config.d/php5_ccpp > /etc/config.d/php8-cli
fi

# write default config file
make_config_file /etc/default.d/${packages_name}

# update from old version
read_old_config

# write new config file
make_config_file /etc/config.d/${packages_name}

# write check.d file
make_check_file

### ---------------------------------------------------------------------------
### end
### ---------------------------------------------------------------------------

