#!/bin/sh
#----------------------------------------------------------------------------
# /var/install/config.d/php8-cli.sh - php8 CGI setup
#
# Copyright (c) 2021 
# Last Update:  $Id: php8-cli.sh 62519 2019-01-21 22:14:22Z schlotze $
#
# Copyright (c) 2021 the eisfair team, team(at)eisfair(dot)org
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#----------------------------------------------------------------------------

pn=php8-cli
php_ini='/etc/php8/cli/php.ini'

. /etc/default.d/${pn}
. /etc/config.d/${pn}
. /var/install/include/eislib
. /etc/config.d/environment

mecho "Creating PHP8-CLI configuration ..."

# debug mode true/false
#debug=true
if ${debug:-false}
then
    case $1 in
        # add function call to trace name
        *installcron|*uninstallcron|*copycrlhashes|*setrights )
            cmd=`echo "$1" | sed 's/^-*//'`
            exec 2>/tmp/$(basename ${0})-config-${cmd}-$$.log
            ;;
        * )
            exec 2>/tmp/$(basename ${0})-config-$$.log
            ;;
    esac

    set -x
    ask_debug=true
    export ask_debug
fi

#---------------------------------------------------------------------------
# set parameter to no
#---------------------------------------------------------------------------
set_parameter_no ()
{
    # ${1} rewrite Parameter from 'yes' to 'no'

    CONFIG_FILE="/etc/config.d/${pn}"

    # set parameter from 'yes' to 'no'
    sed "s/^${1}=.*/${1}='no'/" ${CONFIG_FILE} >/tmp/CONFIG_FILE_TMP
    mv /tmp/CONFIG_FILE_TMP ${CONFIG_FILE}
    chmod 0600 ${CONFIG_FILE}

    return
}

# ---------------------------------------------------------------------------
# create php8 start
# ---------------------------------------------------------------------------
create_PHP8CLI_start()
{
    case ${START_PHP8CLI} in
    yes)
        php5_status=`eisman check php5_ccpp`

        if [ ${php5_status} != "not-installed" ]
        then
            . /etc/config.d/php5_ccpp
            if [ "${START_PHP5CCPP}" = "yes" ]
            then
                START_PHP8CLI="no"
                set_parameter_no "START_PHP8CLI"
                mecho --error "php5_ccpp is installed and enabled. You cannot use php5 and php8 at the same time."                
            fi
        fi

        php7_status=`eisman check php7-cli`

        if [ ${php7_status} != "not-installed" ]
        then
            . /etc/config.d/php7-cli
            if [ "${START_PHP7CLI}" = "yes" ]
            then
                START_PHP8CLI="no"
                set_parameter_no "START_PHP8CLI"
                mecho --error "php7-cli is installed and enabled. You cannot use php7 and php8 at the same time."
            fi
        fi
        ;;
    esac
}

# ---------------------------------------------------------------------------
# deactivate module package
# ---------------------------------------------------------------------------
deactivate_modules () 
{
    rm -f /etc/php8/cli/conf.d/eisfair.ini
    rm -f /etc/php8/cli/conf.d/mysql.ini
    rm -f /etc/php8/cli/conf.d/mysql-conf.ini
    rm -f /etc/php8/cli/conf.d/mssql.ini
    rm -f /etc/php8/cli/conf.d/interbase.ini
    rm -f /etc/php8/cli/conf.d/pgsql.ini
    rm -f /etc/php8/cli/conf.d/sqlite3.ini
    rm -f /etc/php8/cli/conf.d/ldap.ini
    rm -f /etc/php8/cli/conf.d/soap.ini
    rm -f /etc/php8/cli/conf.d/apcu.ini
    rm -f /etc/php8/cli/conf.d/redis.ini
    rm -f /etc/php8/cli/conf.d/advantage.ini
    rm -f /etc/php8/cli/conf.d/suhosin.ini
}

### -------------------------------------------------------------------------
### Set the HTTP_Proxy with username and Password from the
### /etc/config.d/environment file
### -------------------------------------------------------------------------
if [ "${HTTP_PROXY}" != "" ] ; then
    if [ "$HTTP_PROXY_USER" != "" -a "$HTTP_PROXY_PASSWD" != "" ] ; then
        proxy_user="$HTTP_PROXY_USER:$HTTP_PROXY_PASSWD@"
    else
        proxy_user=""
    fi

    pear config-set http_proxy ${proxy_user}${HTTP_PROXY}
fi

# ---------------------------------------------------------------------------
# create config
# ---------------------------------------------------------------------------
create_config()
{
    rm -f /etc/php8/cli/conf.d/eisfair.ini
    # -----------------------------------------------------------------------------
    # Log Error
    # -----------------------------------------------------------------------------
    if [ "${PHP8CLI_LOG_ERROR}" = "yes" ] ; then
        {
            echo "; Log errors into a log file (server-specific log, stderr, or error_log (below))"
            echo "; As stated above, you\re strongly advised to use error logging in place of"
            echo "; error displaying on production web sites."
            echo "log_errors = On"
            echo 
        } >> /etc/php8/cli/conf.d/eisfair.ini
    else
        {
            echo "; Log errors into a log file (server-specific log, stderr, or error_log (below))"
            echo "; As stated above, you\re strongly advised to use error logging in place of"
            echo "; error displaying on production web sites."
            echo "log_errors = Off"
            echo 
        } >> /etc/php8/cli/conf.d/eisfair.ini
    fi
    # -----------------------------------------------------------------------------
    # Display Errors
    # -----------------------------------------------------------------------------
    if [ "${PHP8CLI_DISPLAY_ERRORS}" = "yes" ] ; then
        {
            echo "; Print out errors (as a part of the output).  For production web sites,"
            echo "; you\re strongly encouraged to turn this feature off, and use error logging"
            echo "; instead (see below).  Keeping display_errors enabled on a production web site"
            echo "; may reveal security information to end users, such as file paths on your Web"
            echo "; server, your database schema or other information."
            echo "display_errors = On"
            echo 
        } >> /etc/php8/cli/conf.d/eisfair.ini
    else
        {
            echo "; Print out errors (as a part of the output).  For production web sites,"
            echo "; you\re strongly encouraged to turn this feature off, and use error logging"
            echo "; instead (see below).  Keeping display_errors enabled on a production web site"
            echo "; may reveal security information to end users, such as file paths on your Web"
            echo "; server, your database schema or other information."
            echo "display_errors = Off"
            echo 
        } >> /etc/php8/cli/conf.d/eisfair.ini
    fi
    # -----------------------------------------------------------------------------
    # SendMail Path
    # -----------------------------------------------------------------------------
    if [ -f "${PHP8CLI_SENDMAIL_PATH}" -a "${PHP8CLI_SENDMAIL_PATH}" != "" ]
    then
        {
            echo '; For Unix only.  You may supply arguments as well (default: "sendmail -t -i").'
            echo "sendmail_path = ${PHP8CLI_SENDMAIL_PATH} ${PHP8CLI_SENDMAIL_APP}"
            echo 
        } >> /etc/php8/cli/conf.d/eisfair.ini
    else
        {
            echo '; For Unix only.  You may supply arguments as well (default: "sendmail -t -i").'
            echo "sendmail_path = /usr/sbin/sendmail -t -i"
            echo 
        } >> /etc/php8/cli/conf.d/eisfair.ini
    fi
    
    # -----------------------------------------------------------------------------
    # Date Timezone Settings
    # -----------------------------------------------------------------------------
    {
        echo '[Date]'
        echo '; Defines the default timezone used by the date functions'
        echo "date.timezone = \"${PHP8CLI_DATE_TIMEZONE}\""
        echo
        echo ';date.default_latitude = 31.7667'
        echo ';date.default_longitude = 35.2333'
        echo
        echo ';date.sunrise_zenith = 90.583333'
        echo ';date.sunset_zenith = 90.583333'
    } >> /etc/php8/cli/conf.d/eisfair.ini
    # -----------------------------------------------------------------------------
    # Include Path
    # -----------------------------------------------------------------------------
    {
        echo '; UNIX: "/path1:/path2"'
        echo 'include_path = ".:/usr/share/php8:/usr/include/php8"'
        echo 
    } >> /etc/php8/cli/conf.d/eisfair.ini
    
    # -----------------------------------------------------------------------------
    # Extension Directory
    # -----------------------------------------------------------------------------
    {
        echo '; Directory in which the loadable extensions (modules) reside.'
        echo "extension_dir = /usr/lib/php8/extensions"
    } >> /etc/php8/cli/conf.d/eisfair.ini
    
    # -----------------------------------------------------------------------------
    # Upload directory
    # -----------------------------------------------------------------------------
    if [ -d ${PHP8CLI_UPLOAD_DIR} ] ; then
        {
            echo "; Temporary directory for HTTP uploaded files (will use system default if not"
            echo "; specified)."
            echo "upload_tmp_dir = ${PHP8CLI_UPLOAD_DIR}"
            echo 
        } >> /etc/php8/cli/conf.d/eisfair.ini
    else
        {
            echo "; Temporary directory for HTTP uploaded files (will use system default if not"
            echo "; specified)."
            echo 'upload_tmp_dir = "/tmp"'
            echo 
        } >> /etc/php8/cli/conf.d/eisfair.ini
    fi
    
    # -----------------------------------------------------------------------------
    # 
    # -----------------------------------------------------------------------------
    {
        echo "; Maximum allowed size for uploaded files."
        echo "upload_max_filesize = ${PHP8CLI_MAX_UPLOAD_FILESIZE}"
        echo
        echo "; Maximum execution time of each script, in seconds"
        echo "max_execution_time = ${PHP8CLI_MAX_EXECUTION_TIME}"
        echo
        echo "; Maximum amount of memory a script may consume (8MB)"
        echo "memory_limit = ${PHP8CLI_MEMORY_LIMIT}"
        echo 
        echo "; Maximum size of POST data that PHP will accept."
        echo "post_max_size = ${PHP8CLI_MAX_POST_SIZE}"
        echo 
    } >> /etc/php8/cli/conf.d/eisfair.ini
    # -----------------------------------------------------------------------------
    # load modules
    # -----------------------------------------------------------------------------
    {
        echo "extension = bz2.so"
        echo "extension = curl.so"
        echo "extension = gd.so"
        echo "extension = gettext.so"
        echo "extension = iconv.so"
        echo "extension = mcrypt.so"
        echo "extension = openssl.so"
        echo "extension = pdo.so"
        echo "extension = pdo_dblib.so"
        echo "extension = zlib.so"
        echo 
    } >> /etc/php8/cli/conf.d/eisfair.ini
    
    # -----------------------------------------------------------------------------
    # handling for php8 modules
    # -----------------------------------------------------------------------------
    for NAME in $(ls /etc/php8/conf.d/*.ini); do
    	if [ "$(basename ${NAME})" != "eisfair.ini" ]
    	then
            ln -sf /etc/php8/conf.d/$(basename ${NAME}) /etc/php8/cli/conf.d/$(basename ${NAME})
        fi
    done

    # -----------------------------------------------------------------------------
    # MYSQL
    # -----------------------------------------------------------------------------
    if [ "${PHP8CLI_EXT_MYSQL}" = "yes" ] 
    then
        module_status=`eisman check php8-mysql`
        if [ ${module_status} != "installed" ]
        then
            set_parameter_no "PHP8CLI_EXT_MYSQL"
            mecho --error "You cannot activate MySQL-Extension. You need to install php8-mysql first."                
        else
            if [ -z "$PHP8CLI_EXT_MYSQL_SOCKET" ]
            then
                if [ -z "$PHP8CLI_EXT_MYSQL_HOST" ]
                then
                    if [ -e "/run/mysql/mysql.sock" ]
                    then
                        PHP8CLI_EXT_MYSQL_SOCKET="/run/mysql/mysql.sock"
                    elif [ -e "/var/lib/mysql/mysql.sock" ]
                    then
                        PHP8CLI_EXT_MYSQL_SOCKET="/var/lib/mysql/mysql.sock"
                    fi 
               fi
            fi
            if [ ! -e "$PHP8CLI_EXT_MYSQL_SOCKET" ]
            then
                mecho --error "The MySQL Socket you configured does not exist. Connecting to MySQL will not be possible."
            fi
            if [ -z "$PHP8CLI_EXT_MYSQL_HOST" ]
            then
                PHP8CLI_EXT_MYSQL_PORT=""
            else
                if [ -z "$PHP8CLI_EXT_MYSQL_PORT" ] 
                then
                    PHP8CLI_EXT_MYSQL_PORT="3306"
                fi
            fi
            ln -sf /etc/php8/conf.d/mysql.ini /etc/php8/cli/conf.d/mysql.ini
    
            cat >/etc/php8/cli/conf.d/mysql-conf.ini <<EOF
[mysql]
mysql.allow_local_infile=On
mysql.allow_persistent=On
mysql.cache_size=2000
mysql.max_persistent=-1
mysql.max_links=-1
mysql.default_port=${PHP8CLI_EXT_MYSQL_PORT}
mysql.default_socket=${PHP8CLI_EXT_MYSQL_SOCKET}
mysql.default_host=${PHP8CLI_EXT_MYSQL_HOST}
mysql.default_user=
mysql.default_password=
mysql.connect_timeout=60
mysql.trace_mode=Off
[pdo_mysql]
pdo_mysql.cache_size=2000
pdo_mysql.default_socket=${PHP8CLI_EXT_MYSQL_SOCKET}
[mysqli]
mysqli.max_persistent=-1
mysqli.allow_local_infile=On
mysqli.allow_persistent=On
mysqli.max_links=-1
mysqli.cache_size=2000
mysqli.default_port=${PHP8CLI_EXT_MYSQL_PORT}
mysqli.default_socket=${PHP8CLI_EXT_MYSQL_SOCKET}
mysqli.default_host=${PHP8CLI_EXT_MYSQL_HOST}
mysqli.default_user=
mysqli.default_pw=
mysqli.reconnect=Off
[mysqlnd]
mysqlnd.collect_statistics=On
mysqlnd.collect_memory_statistics=Off
;mysqlnd.net_cmd_buffer_size=2048
;mysqlnd.net_read_buffer_size=32768
EOF
        fi
    else
        rm -f /etc/php8/cli/conf.d/mysql.ini
        rm -f /etc/php8/cli/conf.d/mysql-conf.ini
    fi
    
    # -----------------------------------------------------------------------------
    # INTERBASE
    # -----------------------------------------------------------------------------
    if [ "${PHP8CLI_EXT_INTER}" = "yes" ] ; then
        module_status=`eisman check php8-firebird`
        if [ ${module_status} != "installed" ]
        then
            set_parameter_no "PHP8CLI_EXT_INTER"
            mecho --error "You cannot activate INTERBASE/FIREBIRD-Extension. You need to install php8-firebird first."                
        else
            ln -sf /etc/php8/conf.d/interbase.ini /etc/php8/cli/conf.d/interbase.ini
    
        fi
    else
        rm -f /etc/php8/cli/conf.d/interbase.ini
    fi
    
    # -----------------------------------------------------------------------------
    # MSSQL
    # -----------------------------------------------------------------------------
    if [ "${PHP8CLI_EXT_MSSQL}" = "yes" ] ; then
        cat >/etc/php8/cli/conf.d/mssql.ini <<EOF
extension=pdo_dblib.so

EOF
    else
        rm -f /etc/php8/cli/conf.d/mssql.ini
    fi
    
    # -----------------------------------------------------------------------------
    # POSTGRESQL
    # -----------------------------------------------------------------------------
    if [ "${PHP8CLI_EXT_PGSQL}" = "yes" ] ; then
        module_status=`eisman check php8-pgsql`
        if [ ${module_status} != "installed" ]
        then
            set_parameter_no "PHP8CLI_EXT_PGSQL"
            mecho --error "You cannot activate PGSQL-Extension. You need to install php8-pgsql first."                
        else
            ln -sf /etc/php8/conf.d/pgsql.ini /etc/php8/cli/conf.d/pgsql.ini
        fi
    else
        rm -f /etc/php8/cli/conf.d/pgsql.ini
    fi
    
    # -----------------------------------------------------------------------------
    # SQLite3
    # -----------------------------------------------------------------------------
    if [ "${PHP8CLI_EXT_SQLITE3}" = "yes" ] ; then
        module_status=`eisman check php8-sqlite`
        if [ ${module_status} != "installed" ]
        then
            set_parameter_no "PHP8CLI_EXT_SQLITE3"
            mecho --error "You cannot activate SQLITE-Extension. You need to install php8-sqlite first."                
        else
            ln -sf /etc/php8/conf.d/sqlite3.ini /etc/php8/cli/conf.d/sqlite3.ini 
        fi
    else
        rm -f /etc/php8/cli/conf.d/sqlite3.ini
    fi
    
    # -----------------------------------------------------------------------------
    # SOAP
    # -----------------------------------------------------------------------------
    if [ "${PHP8CLI_EXT_SOAP}" = "yes" ] ; then
        module_status=`eisman check php8-soap`
        if [ ${module_status} != "installed" ]
        then
            set_parameter_no "PHP8CLI_EXT_SOAP"
            mecho --error "You cannot activate SOAP-Extension. You need to install php8-soap first."                
        else
            ln -sf /etc/php8/conf.d/soap.ini /etc/php8/cli/conf.d/soap.ini 
        fi
    else
        rm -f /etc/php8/cli/conf.d/soap.ini
    fi
    
    # -----------------------------------------------------------------------------
    # LDAP
    # -----------------------------------------------------------------------------
    if [ "${PHP8CLI_EXT_LDAP}" = "yes" ] ; then
        module_status=`eisman check php8-ldap`
        if [ ${module_status} != "installed" ]
        then
            set_parameter_no "PHP8CLI_EXT_LDAP"
            mecho --error "You cannot activate LDAP-Extension. You need to install php8-ldap first."                
        else
            ln -sf /etc/php8/conf.d/ldap.ini /etc/php8/cli/conf.d/ldap.ini
        fi
    else
        rm -f /etc/php8/cli/conf.d/ldap.ini
    fi
    
    # -----------------------------------------------------------------------------
    # CACHE
    # -----------------------------------------------------------------------------
    if [ "${PHP8CLI_EXT_CACHE}" = "apcu" ]
    then
        module_status=`eisman check php8-apcu`
        if [ ${module_status} != "installed" ]
        then
            set_parameter_no "PHP8CLI_EXT_CACHE"
            mecho --error "You cannot activate APCU-Extension. You need to install php8-apcu first."                
        else
            ln -sf /etc/php8/conf.d/apcu.ini /etc/php8/cli/conf.d/apcu.ini
        fi
        rm -f /etc/php8/cli/conf.d/redis.ini
    elif [ "${PHP8CLI_EXT_CACHE}" = "redis" ]
    then
        module_status=`eisman check php8-redis`
        if [ ${module_status} != "installed" ]
        then
            set_parameter_no "PHP8CLI_EXT_CACHE"
            mecho --error "You cannot activate REDIS-Extension. You need to install php8-redis first."                
        else
            ln -sf /etc/php8/conf.d/redis.ini /etc/php8/cli/conf.d/redis.ini
        fi
        rm -f /etc/php8/cli/conf.d/apcu.ini
    elif [ "${PHP8CLI_EXT_CACHE}" = "apcu+redis" ]
    then
        module_status=`eisman check php8-apcu`
        if [ ${module_status} != "installed" ]
        then
            set_parameter_no "PHP8CLI_EXT_CACHE"
            mecho --error "You cannot activate APCU-Extension. You need to install php8-apcu first."                
        else
            ln -sf /etc/php8/conf.d/apcu.ini /etc/php8/cli/conf.d/apcu.ini
        fi
        module_status=`eisman check php8-redis`
        if [ ${module_status} != "installed" ]
        then
            set_parameter_no "PHP8CLI_EXT_CACHE"
            mecho --error "You cannot activate REDIS-Extension. You need to install php8-redis first."                
        else
            ln -sf /etc/php8/conf.d/redis.ini /etc/php8/cli/conf.d/redis.ini
        fi
    elif [ "${PHP8CLI_EXT_CACHE}" = "no" ]
    then
        rm -f /etc/php8/cli/conf.d/apcu.ini
        rm -f /etc/php8/cli/conf.d/redis.ini
    fi
    # =============================================================================
    
    
}

# ---------------------------------------------------------------------------
# main
# ---------------------------------------------------------------------------
rm -f /etc/php8/conf.d/eisfair.ini

case "$1" in
    *)
        create_PHP8CLI_start

        if [ "$START_PHP8CLI" = "yes" ]
        then        
            create_config
            echo "php manual /usr/bin/php-8" | /usr/sbin/update-alternatives --set-selections >/dev/null 2>&1
        else
            deactivate_modules
            if [ "${START_PHP5CCPP}" = "yes" ]
            then
                echo "php manual /usr/bin/php-5" | /usr/sbin/update-alternatives --set-selections >/dev/null 2>&1
            fi
        fi            
        ;;
esac

exit 0
# ---------------------------------------------------------------------------
# end
# ---------------------------------------------------------------------------